## jobview

This tool aim for providing Linux cluster users with better visualization to show the status of nodes and assignments in Sun Grid Engine system.

```python
Usage: jobview [OPTIONS] COMMAND [ARGS]...

  用于SGE系统的节点资源查看，任务资源显示和消耗记录的工具
  Tools for better recording and visualizing computer resources of Sun Grid Engine(SGE) System

Options:
  --help  Show this message and exit.

Commands:
  nodes   展示指定用户所有可用节点的资源使用情况
  status  更全面和方便的展示投递任务情况
  track   跟踪任务资源消耗情况，并生成图片和总结报告

```
